@@ -218,7 +218,7 @@ class OwnershipState(BaseOwnershipState):
             result = False
         return result
 
-    def _update(self, tx_message: TransactionMessage) -> None:
+    def update(self, tx_message: TransactionMessage) -> None:
         """
         Update the agent state from a transaction.
 
@@ -246,7 +246,7 @@ class OwnershipState(BaseOwnershipState):
         """
         new_state = copy.copy(self)
         for tx_message in transactions:
-            new_state._update(tx_message)
+            new_state.update(tx_message)
 
         return new_state
 
@@ -315,9 +315,7 @@ class Preferences(BasePreferences):
     """Class to represent the preferences."""
 
     def __init__(self):
-        """
-        Instantiate an agent preference object.
-        """
+        """Instantiate an agent preference object."""
         self._exchange_params_by_currency_id = None  # type: Optional[ExchangeParams]
         self._utility_params_by_good_id = None  # type: Optional[UtilityParams]
         self._transaction_fees = None  # type: Optional[Dict[str, int]]
@@ -800,7 +798,6 @@ class DecisionMakerHandler(BaseDecisionMakerHandler):
         """
         Check if the transaction message contains a valid ledger transaction.
 
-
         :param tx_message: the transaction message
         :return: whether the transaction is valid
         """
