@@ -36,6 +36,7 @@ class Location:
     def __init__(self, latitude: float, longitude: float):
         """
         Initialize a location.
+
         :param latitude: the latitude of the location.
         :param longitude: the longitude of the location.
         """
@@ -52,6 +53,7 @@ class Location:
         return haversine(self.latitude, self.longitude, other.latitude, other.longitude)
 
     def __eq__(self, other):
+        """Compare equality of two locations."""
         if not isinstance(other, Location):
             return False
         else:
@@ -68,6 +70,7 @@ ALLOWED_ATTRIBUTE_TYPES = [float, str, bool, int, Location]
 class AttributeInconsistencyException(Exception):
     """
     Raised when the attributes in a Description are inconsistent.
+
     Inconsistency is defined when values do not meet their respective schema, or if the values
     are not of an allowed type.
     """
@@ -207,7 +210,8 @@ class Description:
 
     def _check_consistency(self):
         """
-        Checks the consistency of the values of this description.
+        Check the consistency of the values of this description.
+
         If an attribute has been provided, values are checked against that. If no attribute
         schema has been provided then minimal checking is performed based on the values in the
         provided attribute_value dictionary.
@@ -339,9 +343,9 @@ class ConstraintType:
         """
         self.type = ConstraintTypes(type)
         self.value = value
-        assert self._check_validity(), "ConstraintType initialization inconsistent."
+        assert self.check_validity(), "ConstraintType initialization inconsistent."
 
-    def _check_validity(self):
+    def check_validity(self):
         """
         Check the validity of the input provided.
 
@@ -495,7 +499,7 @@ class ConstraintExpr(ABC):
     @abstractmethod
     def is_valid(self, data_model: DataModel) -> bool:
         """
-        Check whether a constraint expression is valid wrt a data model
+        Check whether a constraint expression is valid wrt a data model.
 
          Specifically, check the following conditions:
         - If all the attributes referenced by the constraints are correctly associated with the Data Model attributes.
@@ -504,7 +508,7 @@ class ConstraintExpr(ABC):
         :return: ``True`` if the constraint expression is valid wrt the data model, ``False`` otherwise.
         """
 
-    def _check_validity(self) -> None:
+    def check_validity(self) -> None:
         """
         Check whether a Constraint Expression satisfies some basic requirements.
 
@@ -536,14 +540,14 @@ class And(ConstraintExpr):
 
     def is_valid(self, data_model: DataModel) -> bool:
         """
-        Check whether the constraint expression is valid wrt a data model
+        Check whether the constraint expression is valid wrt a data model.
 
         :param data_model: the data model used to check the validity of the constraint expression.
         :return: ``True`` if the constraint expression is valid wrt the data model, ``False`` otherwise.
         """
         return all(constraint.is_valid(data_model) for constraint in self.constraints)
 
-    def _check_validity(self):
+    def check_validity(self):
         """
         Check whether the Constraint Expression satisfies some basic requirements.
 
@@ -556,7 +560,7 @@ class And(ConstraintExpr):
                 "subexpression must be at least 2.".format(type(self).__name__)
             )
         for constraint in self.constraints:
-            constraint._check_validity()
+            constraint.check_validity()
 
     def __eq__(self, other):
         """Compare with another object."""
@@ -585,14 +589,14 @@ class Or(ConstraintExpr):
 
     def is_valid(self, data_model: DataModel) -> bool:
         """
-        Check whether the constraint expression is valid wrt a data model
+        Check whether the constraint expression is valid wrt a data model.
 
         :param data_model: the data model used to check the validity of the constraint expression.
         :return: ``True`` if the constraint expression is valid wrt the data model, ``False`` otherwise.
         """
         return all(constraint.is_valid(data_model) for constraint in self.constraints)
 
-    def _check_validity(self):
+    def check_validity(self):
         """
         Check whether the Constraint Expression satisfies some basic requirements.
 
@@ -605,7 +609,7 @@ class Or(ConstraintExpr):
                 "subexpression must be at least 2.".format(type(self).__name__)
             )
         for constraint in self.constraints:
-            constraint._check_validity()
+            constraint.check_validity()
 
     def __eq__(self, other):
         """Compare with another object."""
@@ -634,7 +638,7 @@ class Not(ConstraintExpr):
 
     def is_valid(self, data_model: DataModel) -> bool:
         """
-        Check whether the constraint expression is valid wrt a data model
+        Check whether the constraint expression is valid wrt a data model.
 
         :param data_model: the data model used to check the validity of the constraint expression.
         :return: ``True`` if the constraint expression is valid wrt the data model, ``False`` otherwise.
@@ -725,7 +729,7 @@ class Constraint(ConstraintExpr):
 
     def is_valid(self, data_model: DataModel) -> bool:
         """
-        Check whether the constraint expression is valid wrt a data model
+        Check whether the constraint expression is valid wrt a data model.
 
         :param data_model: the data model used to check the validity of the constraint expression.
         :return: ``True`` if the constraint expression is valid wrt the data model, ``False`` otherwise.
@@ -760,7 +764,7 @@ class Query:
         """
         self.constraints = constraints
         self.model = model
-        self._check_validity()
+        self.check_validity()
 
     def check(self, description: Description) -> bool:
         """
@@ -776,6 +780,7 @@ class Query:
     def is_valid(self, data_model: DataModel) -> bool:
         """
         Given a data model, check whether the query is valid for that data model.
+
         :return: ``True`` if the query is compliant with the data model, ``False`` otherwise.
         """
         if data_model is None:
@@ -783,7 +788,7 @@ class Query:
 
         return all(c.is_valid(data_model) for c in self.constraints)
 
-    def _check_validity(self):
+    def check_validity(self):
         """
         Check whether the` object is valid.
 
@@ -847,6 +852,7 @@ class Query:
 def haversine(lat1: float, lon1: float, lat2: float, lon2: float) -> float:
     """
     Compute the Haversine distance between two locations (i.e. two pairs of latitude and longitude).
+
     :param lat1: the latitude of the first location.
     :param lon1: the longitude of the first location.
     :param lat2: the latitude of the second location.
