@@ -17,6 +17,7 @@
 #
 # ------------------------------------------------------------------------------
 """This module contains the implementation of runtime for economic agent (AEA)."""
+
 import asyncio
 import logging
 import threading
@@ -106,6 +107,15 @@ class BaseRuntime(ABC):
         """Get stopped state of the runtime."""
         return self._state.get() == RuntimeStates.stopped
 
+    def set_loop(self, loop: AbstractEventLoop) -> None:
+        """
+        Set event loop to be used.
+
+        :param loop: event loop to use.
+        """
+        self._loop = loop
+        asyncio.set_event_loop(self._loop)
+
 
 class AsyncRuntime(BaseRuntime):
     """Asynchronous runtime: uses asyncio loop for multiplexer and async agent main loop."""
@@ -125,6 +135,17 @@ class AsyncRuntime(BaseRuntime):
         self._async_stop_lock: Optional[asyncio.Lock] = None
         self._task: Optional[asyncio.Task] = None
 
+    def set_loop(self, loop: AbstractEventLoop) -> None:
+        """
+        Set event loop to be used.
+
+        :param loop: event loop to use.
+        """
+        super().set_loop(loop)
+        self._agent.multiplexer.set_loop(self._loop)
+        self._agent.main_loop.set_loop(self._loop)
+        self._async_stop_lock = asyncio.Lock()
+
     def _start(self) -> None:
         """
         Start runtime synchronously.
@@ -136,17 +157,14 @@ class AsyncRuntime(BaseRuntime):
         if self._state.get() is RuntimeStates.started:
             raise ValueError("Runtime already started!")
 
-        asyncio.set_event_loop(self._loop)
-        self._agent._multiplexer.set_loop(self._loop)
-        self._agent._main_loop.set_loop(self._loop)
+        self.set_loop(self._loop)
 
         self._state.set(RuntimeStates.started)
 
         self._thread = threading.current_thread()
-        self._async_stop_lock = asyncio.Lock()
 
         logger.debug(f"Start runtime event loop {self._loop}: {id(self._loop)}")
-        self._task = self._loop.create_task(self._run_runtime())
+        self._task = self._loop.create_task(self.run_runtime())
 
         try:
             self._loop.run_until_complete(self._task)
@@ -158,12 +176,13 @@ class AsyncRuntime(BaseRuntime):
         finally:
             self._stopping_task = None
 
-    async def _run_runtime(self) -> None:
+    async def run_runtime(self) -> None:
         """Run agent and starts multiplexer."""
         try:
             self._state.set(RuntimeStates.starting)
+            self._agent.setup_multiplexer()
             await self._start_multiplexer()
-            self._agent._start_setup()
+            self._agent.start_setup()
             await self._start_agent_loop()
         except Exception:
             logger.exception("AsyncRuntime exception during run:")
@@ -174,17 +193,17 @@ class AsyncRuntime(BaseRuntime):
 
     async def _multiplexer_disconnect(self) -> None:
         """Call multiplexer disconnect asynchronous way."""
-        await AsyncMultiplexer.disconnect(self._agent._multiplexer)
+        await AsyncMultiplexer.disconnect(self._agent.multiplexer)
 
     async def _start_multiplexer(self) -> None:
         """Call multiplexer connect asynchronous way."""
-        await AsyncMultiplexer.connect(self._agent._multiplexer)
+        await AsyncMultiplexer.connect(self._agent.multiplexer)
 
     async def _start_agent_loop(self) -> None:
         """Start agent main loop asynchronous way."""
         logger.debug("[{}]: Runtime started".format(self._agent.name))
         self._state.set(RuntimeStates.started)
-        await self._agent._main_loop._run_loop()
+        await self._agent.main_loop.run_loop()
 
     async def _stop_runtime(self) -> None:
         """
@@ -204,11 +223,11 @@ class AsyncRuntime(BaseRuntime):
                     return
 
                 self._state.set(RuntimeStates.stopping)
-                self._agent._main_loop.stop()
+                self._agent.main_loop.stop()
 
                 try:
-                    await self._agent._main_loop._wait_run_loop_stopped()
-                except BaseException:  # nosec
+                    await self._agent.main_loop.wait_run_loop_stopped()
+                except BaseException:  # nosec # pylint: disable=broad-except
                     # on stop we do not care about exceptions here, it should be raised in _start.
                     pass  # nosec
 
@@ -237,7 +256,7 @@ class AsyncRuntime(BaseRuntime):
             try:
                 # dummy spin to cleanup some stuff if it was interrupted
                 self._loop.run_until_complete(asyncio.sleep(0.01))
-            except BaseException:  # nosec
+            except BaseException:  # nosec # pylint: disable=broad-except
                 pass  # nosec
 
             self._loop.run_until_complete(self._stop_runtime())
@@ -258,22 +277,24 @@ class ThreadedRuntime(BaseRuntime):
 
         self._agent.multiplexer.set_loop(asyncio.new_event_loop())
 
+        self._agent.setup_multiplexer()
         self._agent.multiplexer.connect()
-        self._agent._start_setup()
+        self._agent.start_setup()
         self._start_agent_loop()
 
     def _start_agent_loop(self) -> None:
+        """Start aget's main loop."""
         logger.debug("[{}]: Runtime started".format(self._agent.name))
         try:
             self._state.set(RuntimeStates.started)
-            self._agent._main_loop.start()
+            self._agent.main_loop.start()
         finally:
             self._state.set(RuntimeStates.loop_stopped)
 
     def _stop(self) -> None:
         """Implement runtime stop function here."""
         self._state.set(RuntimeStates.stopping)
-        self._agent._main_loop.stop()
+        self._agent.main_loop.stop()
         self._teardown()
         self._agent.multiplexer.disconnect()
         logger.debug("[{}]: Runtime stopped".format(self._agent.name))
