@@ -29,7 +29,7 @@ from aea.skills.base import Handler
 class MyScaffoldHandler(Handler):
     """This class scaffolds a handler."""
 
-    SUPPORTED_PROTOCOL = ''  # type: Optional[ProtocolId]
+    SUPPORTED_PROTOCOL = None  # type: Optional[ProtocolId]
 
     def setup(self) -> None:
         """
@@ -39,12 +39,11 @@ class MyScaffoldHandler(Handler):
         """
         raise NotImplementedError  # pragma: no cover
 
-    def handle(self, message: Message, sender: str) -> None:
+    def handle(self, message: Message) -> None:
         """
         Implement the reaction to an envelope.
 
         :param message: the message
-        :param sender: the sender
         :return: None
         """
         raise NotImplementedError  # pragma: no cover
