@@ -27,19 +27,19 @@ from typing import Dict, Optional, cast
 
 import gym
 
-from aea.configurations.base import ConnectionConfig, PublicId
+from aea.configurations.base import PublicId
 from aea.connections.base import Connection
 from aea.helpers.base import locate
 from aea.mail.base import Address, Envelope
 
 from packages.fetchai.protocols.gym.message import GymMessage
-from packages.fetchai.protocols.gym.serialization import GymSerializer
 
 logger = logging.getLogger("aea.packages.fetchai.connections.gym")
 
 
 """default 'to' field for Gym envelopes."""
 DEFAULT_GYM = "gym"
+PUBLIC_ID = PublicId.from_str("fetchai/gym:0.2.0")
 
 
 class GymChannel:
@@ -84,7 +84,7 @@ class GymChannel:
         :param envelope: the envelope
         :return: None
         """
-        if envelope.protocol_id == PublicId.from_str("fetchai/gym:0.1.0"):
+        if envelope.protocol_id == GymMessage.protocol_id:
             self.handle_gym_message(envelope)
         else:
             raise ValueError("This protocol is not valid for gym.")
@@ -96,8 +96,10 @@ class GymChannel:
         :param envelope: the envelope
         :return: None
         """
-        gym_message = GymSerializer().decode(envelope.message)
-        gym_message = cast(GymMessage, gym_message)
+        assert isinstance(
+            envelope.message, GymMessage
+        ), "Message not of type GymMessage"
+        gym_message = cast(GymMessage, envelope.message)
         if gym_message.performative == GymMessage.Performative.ACT:
             action = gym_message.action.any
             step_id = gym_message.step_id
@@ -110,12 +112,11 @@ class GymChannel:
                 info=GymMessage.AnyObject(info),
                 step_id=step_id,
             )
-            msg_bytes = GymSerializer().encode(msg)
             envelope = Envelope(
                 to=envelope.sender,
                 sender=DEFAULT_GYM,
                 protocol_id=GymMessage.protocol_id,
-                message=msg_bytes,
+                message=msg,
             )
             self._send(envelope)
         elif gym_message.performative == GymMessage.Performative.RESET:
@@ -145,17 +146,21 @@ class GymChannel:
 class GymConnection(Connection):
     """Proxy to the functionality of the gym."""
 
-    def __init__(self, gym_env: gym.Env, **kwargs):
+    connection_id = PUBLIC_ID
+
+    def __init__(self, gym_env: Optional[gym.Env] = None, **kwargs):
         """
         Initialize a connection to a local gym environment.
 
-        :param gym_env: the gym environment.
+        :param gym_env: the gym environment (this cannot be loaded by AEA loader).
         :param kwargs: the keyword arguments of the parent class.
         """
-        if kwargs.get("configuration") is None and kwargs.get("connection_id") is None:
-            kwargs["connection_id"] = PublicId("fetchai", "gym", "0.1.0")
-
         super().__init__(**kwargs)
+        if gym_env is None:
+            gym_env_package = cast(str, self.configuration.config.get("env"))
+            assert gym_env_package is not None, "env must be set!"
+            gym_env_class = locate(gym_env_package)
+            gym_env = gym_env_class()
         self.channel = GymChannel(self.address, gym_env)
 
     async def connect(self) -> None:
@@ -217,18 +222,3 @@ class GymConnection(Connection):
         :return: None
         """
         self._connection = None
-
-    @classmethod
-    def from_config(
-        cls, address: Address, configuration: ConnectionConfig
-    ) -> "Connection":
-        """
-        Get the Gym connection from the connection configuration.
-
-        :param address: the address of the agent.
-        :param configuration: the connection configuration object.
-        :return: the connection object
-        """
-        gym_env_package = cast(str, configuration.config.get("env"))
-        gym_env = locate(gym_env_package)
-        return GymConnection(gym_env(), address=address, configuration=configuration,)
