@@ -24,7 +24,6 @@ from typing import cast
 from aea.skills.behaviours import TickerBehaviour
 
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
-from packages.fetchai.protocols.oef_search.serialization import OefSearchSerializer
 from packages.fetchai.skills.generic_buyer.strategy import Strategy
 
 DEFAULT_SEARCH_INTERVAL = 5.0
@@ -77,12 +76,8 @@ class MySearchBehaviour(TickerBehaviour):
                 dialogue_reference=(str(search_id), ""),
                 query=query,
             )
-            self.context.outbox.put_message(
-                to=self.context.search_service_address,
-                sender=self.context.agent_address,
-                protocol_id=OefSearchMessage.protocol_id,
-                message=OefSearchSerializer().encode(oef_msg),
-            )
+            oef_msg.counterparty = self.context.search_service_address
+            self.context.outbox.put_message(message=oef_msg)
 
     def teardown(self) -> None:
         """
