@@ -28,11 +28,9 @@ from aea.helpers.dialogue.base import DialogueLabel
 from aea.helpers.search.models import Description
 from aea.protocols.base import Message
 from aea.protocols.default.message import DefaultMessage
-from aea.protocols.default.serialization import DefaultSerializer
 from aea.skills.base import Handler
 
 from packages.fetchai.protocols.fipa.message import FipaMessage
-from packages.fetchai.protocols.fipa.serialization import FipaSerializer
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 from packages.fetchai.skills.generic_buyer.dialogues import Dialogue, Dialogues
 from packages.fetchai.skills.generic_buyer.strategy import Strategy
@@ -101,14 +99,10 @@ class FIPAHandler(Handler):
             performative=DefaultMessage.Performative.ERROR,
             error_code=DefaultMessage.ErrorCode.INVALID_DIALOGUE,
             error_msg="Invalid dialogue.",
-            error_data={"fipa_message": FipaSerializer().encode(msg)},
-        )
-        self.context.outbox.put_message(
-            to=msg.counterparty,
-            sender=self.context.agent_address,
-            protocol_id=DefaultMessage.protocol_id,
-            message=DefaultSerializer().encode(default_msg),
+            error_data={"fipa_message": msg.encode()},
         )
+        default_msg.counterparty = msg.counterparty
+        self.context.outbox.put_message(message=default_msg)
 
     def _handle_propose(self, msg: FipaMessage, dialogue: Dialogue) -> None:
         """
@@ -145,12 +139,7 @@ class FIPAHandler(Handler):
             )
             accept_msg.counterparty = msg.counterparty
             dialogue.update(accept_msg)
-            self.context.outbox.put_message(
-                to=msg.counterparty,
-                sender=self.context.agent_address,
-                protocol_id=FipaMessage.protocol_id,
-                message=FipaSerializer().encode(accept_msg),
-            )
+            self.context.outbox.put_message(message=accept_msg)
         else:
             self.context.logger.info(
                 "[{}]: declining the proposal from sender={}".format(
@@ -165,12 +154,7 @@ class FIPAHandler(Handler):
             )
             decline_msg.counterparty = msg.counterparty
             dialogue.update(decline_msg)
-            self.context.outbox.put_message(
-                to=msg.counterparty,
-                sender=self.context.agent_address,
-                protocol_id=FipaMessage.protocol_id,
-                message=FipaSerializer().encode(decline_msg),
-            )
+            self.context.outbox.put_message(message=decline_msg)
 
     def _handle_decline(self, msg: FipaMessage, dialogue: Dialogue) -> None:
         """
@@ -250,12 +234,7 @@ class FIPAHandler(Handler):
             )
             inform_msg.counterparty = msg.counterparty
             dialogue.update(inform_msg)
-            self.context.outbox.put_message(
-                to=msg.counterparty,
-                sender=self.context.agent_address,
-                protocol_id=FipaMessage.protocol_id,
-                message=FipaSerializer().encode(inform_msg),
-            )
+            self.context.outbox.put_message(message=inform_msg)
             self.context.logger.info(
                 "[{}]: informing counterparty={} of payment.".format(
                     self.context.agent_name, msg.counterparty[-5:]
@@ -358,12 +337,7 @@ class OEFSearchHandler(Handler):
             )
             cfp_msg.counterparty = opponent_addr
             dialogues.update(cfp_msg)
-            self.context.outbox.put_message(
-                to=opponent_addr,
-                sender=self.context.agent_address,
-                protocol_id=FipaMessage.protocol_id,
-                message=FipaSerializer().encode(cfp_msg),
-            )
+            self.context.outbox.put_message(message=cfp_msg)
         else:
             self.context.logger.info(
                 "[{}]: found no agents, continue searching.".format(
@@ -415,13 +389,9 @@ class MyTransactionHandler(Handler):
                 performative=FipaMessage.Performative.INFORM,
                 info=json_data,
             )
-            dialogue.outgoing_extend(inform_msg)
-            self.context.outbox.put_message(
-                to=counterparty_addr,
-                sender=self.context.agent_address,
-                protocol_id=FipaMessage.protocol_id,
-                message=FipaSerializer().encode(inform_msg),
-            )
+            inform_msg.counterparty = counterparty_addr
+            dialogue.update(inform_msg)
+            self.context.outbox.put_message(message=inform_msg)
             self.context.logger.info(
                 "[{}]: informing counterparty={} of transaction digest.".format(
                     self.context.agent_name, counterparty_addr[-5:]
