@@ -33,7 +33,9 @@ MODULES_TO_PATH = {
     "aea.aea_builder": "api/aea_builder.md",
     "aea.agent": "api/agent.md",
     "aea.agent_loop": "api/agent_loop.md",
+    "aea.launcher": "api/launcher.md",
     "aea.multiplexer": "api/multiplexer.md",
+    "aea.runner": "api/runner.md",
     "aea.runtime": "api/runtime.md",
     "aea.components.base": "api/components/base.md",
     "aea.components.loader": "api/components/loader.md",
