@@ -35,7 +35,7 @@ from ...conftest import AUTHOR
 @mock.patch("aea.cli.registry.push.os.getcwd", return_value="cwd")
 @mock.patch("aea.cli.registry.push._compress_dir")
 @mock.patch(
-    "aea.cli.registry.push._load_yaml",
+    "aea.cli.registry.push.load_yaml",
     return_value={
         "description": "some-description",
         "version": "some-version",
@@ -54,7 +54,7 @@ class PushItemTestCase(TestCase):
         self,
         path_exists_mock,
         request_api_mock,
-        _load_yaml_mock,
+        load_yaml_mock,
         compress_mock,
         getcwd_mock,
         rm_tarfiles_mock,
@@ -85,7 +85,7 @@ class PushItemTestCase(TestCase):
         self,
         path_exists_mock,
         request_api_mock,
-        _load_yaml_mock,
+        load_yaml_mock,
         compress_mock,
         getcwd_mock,
         rm_tarfiles_mock,
