@@ -25,10 +25,12 @@ from threading import Thread
 from typing import List, Optional
 
 from aea.agent import Agent
+from aea.configurations.base import ConnectionConfig
 from aea.connections.base import Connection
 from aea.connections.stub.connection import StubConnection
 from aea.identity.base import Identity
 from aea.mail.base import Envelope
+from aea.protocols.default.message import DefaultMessage
 
 
 INPUT_FILE = "input_file"
@@ -49,11 +51,15 @@ class MyAgent(Agent):
         print("React called for tick {}".format(self.tick))
         while not self.inbox.empty():
             envelope = self.inbox.get_nowait()  # type: Optional[Envelope]
-            if envelope is not None:
+            if (
+                envelope is not None
+                and envelope.protocol_id == DefaultMessage.protocol_id
+            ):
                 sender = envelope.sender
                 receiver = envelope.to
                 envelope.to = sender
                 envelope.sender = receiver
+                envelope.message = DefaultMessage.serializer.decode(envelope.message)
                 print(
                     "Received envelope from {} with protocol_id={}".format(
                         sender, envelope.protocol_id
@@ -79,9 +85,12 @@ def run():
     identity = Identity(name="my_agent", address="some_address")
 
     # Set up the stub connection
-    stub_connection = StubConnection(
-        input_file_path=INPUT_FILE, output_file_path=OUTPUT_FILE
+    configuration = ConnectionConfig(
+        input_file_path=INPUT_FILE,
+        output_file_path=OUTPUT_FILE,
+        connection_id=StubConnection.connection_id,
     )
+    stub_connection = StubConnection(configuration=configuration, identity=identity)
 
     # Create our Agent
     my_agent = MyAgent(identity, [stub_connection])
@@ -96,17 +105,17 @@ def run():
 
         # Create a message inside an envelope and get the stub connection to pass it into the agent
         message_text = (
-            "my_agent,other_agent,fetchai/default:0.1.0,\x08\x01*\x07\n\x05hello,"
+            b"my_agent,other_agent,fetchai/default:0.2.0,\x08\x01*\x07\n\x05hello,"
         )
-        with open(INPUT_FILE, "w") as f:
+        with open(INPUT_FILE, "wb") as f:
             f.write(message_text)
 
         # Wait for the envelope to get processed
         time.sleep(2)
 
         # Read the output envelope generated by the agent
-        with open(OUTPUT_FILE, "r") as f:
-            print("output message: " + f.readline())
+        with open(OUTPUT_FILE, "rb") as f:
+            print("output message: " + f.readline().decode("utf-8"))
     finally:
         # Shut down the agent
         my_agent.stop()
