@@ -34,7 +34,7 @@ from aea.crypto.wallet import Wallet
 from aea.identity.base import Identity
 from aea.protocols.base import Protocol
 from aea.registries.resources import Resources
-from aea.skills.base import Skill, SkillContext
+from aea.skills.base import Skill
 
 from packages.fetchai.connections.oef.connection import OEFConnection
 from packages.fetchai.skills.weather_client.strategy import Strategy
@@ -64,9 +64,7 @@ def run():
     resources = Resources()
 
     # create the AEA
-    my_aea = AEA(
-        identity, [oef_connection], wallet, ledger_apis, resources,  # stub_connection,
-    )
+    my_aea = AEA(identity, wallet, ledger_apis, resources,)  # stub_connection,
 
     # Add the default protocol (which is part of the AEA distribution)
     default_protocol = Protocol.from_dir(os.path.join(AEA_DIR, "protocols", "default"))
@@ -84,21 +82,16 @@ def run():
     )
     resources.add_protocol(fipa_protocol)
 
+    # Add the OEF connection
+    resources.add_connection(oef_connection)
+
     # Add the error and weather_station skills
-    error_skill_context = SkillContext()
-    error_skill_context.set_agent_context(my_aea.context)
-    logger_name = "aea.packages.fetchai.skills.error"
-    error_skill_context.logger = logging.getLogger(logger_name)
     error_skill = Skill.from_dir(
-        os.path.join(AEA_DIR, "skills", "error"), skill_context=error_skill_context
+        os.path.join(AEA_DIR, "skills", "error"), agent_context=my_aea.context
     )
-    weather_skill_context = SkillContext()
-    weather_skill_context.set_agent_context(my_aea.context)
-    logger_name = "aea.packages.fetchai.skills.error"
-    weather_skill_context.logger = logging.getLogger(logger_name)
     weather_skill = Skill.from_dir(
         os.path.join(ROOT_DIR, "packages", "fetchai", "skills", "weather_client"),
-        skill_context=weather_skill_context,
+        agent_context=my_aea.context,
     )
 
     strategy = cast(Strategy, weather_skill.models.get("strategy"))
